@@ -102,8 +102,8 @@ class Drive(NetBoxModel):
         return Partition.objects.filter(drive=self).count()
 
     def free_space_on_drive(self):
-        print(f"Free Space: {Partition.objects.filter(drive=self).aggregate(Sum('size'))}")
-        return 0
+        print(f"Free Space: {Partition.objects.filter(drive=self).aggregate(Sum('size'))['size__sum']}")
+        return self.size - Partition.objects.filter(drive=self).aggregate(Sum('size'))['size__sum']
 
     def device_name(self):
         return f'/dev/sd{chr(ord("`") + int(self.identifier[-1]))}'
