@@ -1,3 +1,5 @@
+import django_tables2 as tables
+
 from netbox.tables import (
     NetBoxTable,
     ToggleColumn,
@@ -10,6 +12,12 @@ class PhysicalVolumeTable(NetBoxTable):
     """Table for displaying VolumeGroup objects."""
 
     pk = ToggleColumn()
+    linux_device = tables.Column(
+        linkify=True
+    )
+    vg = tables.Column(
+        linkify=True
+    )
 
     class Meta(NetBoxTable.Meta):
         model = PhysicalVolume
