@@ -51,7 +51,7 @@ class PlatformTemplateContent(PluginTemplateExtension):
             partition_dict = {}
             for drive_id in drives_id:
                 drive = Drive.objects.get(pk=drive_id['drive'])
-                print(f"{drive.free_space_on_drive}")
+                print(f"{drive.free_space_on_drive()}")
                 if Partition.objects.filter(drive=drive).count() == 0:
                     partition_dict[drive] = None
                 else:
